; Based on:
; System Management BIOS (SMBIOS) Reference Specification
; Version 2.5
; Status: Final Standard
; September 5, 2006
; DSP0134
;
; http://www.dmtf.org/standards/smbios
;
; Following for non-EFI systems that support the table-based
; access method for the SMBIOS structures, first defined in
; version 2.1 of the SMBIOS standard, released 06/16/1997.

; SMBIOS Structure Table Entry Point Structure.

SMB_ENTRY_POINT_STRUCTURE struct
  epsAnchorString       db 4 dup(?)
  epsChecksum           db ?
  epsLength             db ?
  smbMajorVersion       db ?
  smbMinorVersion       db ?
  maxStructureSize      dw ?
  epRevision            db ?
  formattedArea         db 5 dup(?)
  ;; Start of Intermediate Entry Point Structure (DMI).
  iepsAnchorString      db 5 dup(?)
  iepsChecksum          db ?
  structureTableLength  dw ?
  structureTableAddress dd ?
  numberOfStructures    dw ?
  bcdRevision           db ?
SMB_ENTRY_POINT_STRUCTURE ends

; Four-byte header that each SMBIOS structure begins with.

SMB_STRUCTURE_HEADER struct
  structureType   db ?
  formattedLength db ?
  structureHandle dw ?
SMB_STRUCTURE_HEADER ends

; Type equates for required structures (SMBIOS v2.3+).

SMB_TYPE_BIOS_INFO                    equ 0
SMB_TYPE_SYSTEM_INFO                  equ 1
SMB_TYPE_SYSTEM_ENCLOSURE             equ 3
SMB_TYPE_PROCESSOR_INFO               equ 4
SMB_TYPE_CACHE_INFO                   equ 7
SMB_TYPE_SYSTEM_SLOTS                 equ 9
SMB_TYPE_PHYSICAL_MEMORY_ARRAY        equ 16
SMB_TYPE_MEMORY_DEVICE                equ 17
SMB_TYPE_MEMORY_ARRAY_MAPPED_ADDRESS  equ 19
SMB_TYPE_SYSTEM_BOOT_INFO             equ 32

; Necessary additional type equates.

SMB_TYPE_INACTIVE                     equ 126
SMB_TYPE_END_OF_TABLE                 equ 127

; Required structures and associated equates.

; BIOS Information Structure for SMBIOS version < 2.1.

SMB_BIOS_INFO struct
  header        SMB_STRUCTURE_HEADER <>
  vendor$       db ?
  version$      db ?
  startSeg      dw ?
  releaseDate$  db ?
  romSize       db ?
  charBits      dq ?
SMB_BIOS_INFO ends

; BIOS Information Structure for SMBIOS version 2.1 and 2.2.

SMB_BIOS_INFO_2122 struct
  header        SMB_STRUCTURE_HEADER <>
  vendor$       db ?
  version$      db ?
  startSeg      dw ?
  releaseDate$  db ?
  romSize       db ?
  charBits      dq ?
  extByte1      db ?
SMB_BIOS_INFO_2122 ends

; BIOS Information Structure for SMBIOS version 2.3.

SMB_BIOS_INFO_23 struct
  header        SMB_STRUCTURE_HEADER <>
  vendor$       db ?
  version$      db ?
  startSeg      dw ?
  releaseDate$  db ?
  romSize       db ?
  charBits      dq ?
  extByte1      db ?
  extByte2      db ?
SMB_BIOS_INFO_23 ends

; BIOS Information Structure for SMBIOS version 2.4+.

SMB_BIOS_INFO_24 struct
  header            SMB_STRUCTURE_HEADER <>
  vendor$           db ?
  version$          db ?
  startSeg          dw ?
  releaseDate$      db ?
  romSize           db ?
  charBits          dq ?
  extByte1          db ?
  extByte2          db ?
  systemBIOSMajor   db ?
  systemBIOSMinor   db ?
  ctrlFirmwareMajor db ?
  ctrlFirmwareMinor db ?
SMB_BIOS_INFO_24 ends

; Equates for BIOS Characteristics (charBits).

CHAR_UNKNOWN        equ 4
CHAR_NOT_SUPPORTED  equ 8
CHAR_ISA            equ 10h
CHAR_MCA            equ 20h
CHAR_EISA           equ 40h
CHAR_PCI            equ 80h
CHAR_PCCARD         equ 100h
CHAR_PNP            equ 200h
CHAR_APM            equ 400h
CHAR_FLASH          equ 800h
CHAR_SHADOW         equ 1000h
CHAR_VESA           equ 2000h
CHAR_ESCD           equ 4000h
CHAR_BOOTCD         equ 8000h
CHAR_BOOTSEL        equ 10000h
CHAR_ROMSOCKET      equ 20000h
CHAR_BOOTCARD       equ 40000h
CHAR_EDD            equ 80000h
CHAR_INT13_NEC12    equ 100000h
CHAR_INT13_TOS12    equ 200000h
CHAR_INT13_360      equ 400000h
CHAR_INT13_12       equ 800000h
CHAR_INT13_720      equ 1000000h
CHAR_INT13_288      equ 2000000h
CHAR_INT5           equ 4000000h
CHAR_INT9           equ 8000000h
CHAR_INT14          equ 10000000h
CHAR_INT17          equ 20000000h
CHAR_INT10_CGA_MONO equ 40000000h
CHAR_NECPC98        equ 80000000h

; Equates for BIOS Characteristics Extension Byte 1 (extByte1).

EXTBYTE1_ACPI         equ 1
EXTBYTE1_USBLEGACY    equ 2
EXTBYTE1_AGP          equ 4
EXTBYTE1_BOOTI2O      equ 8
EXTBYTE1_BOOTLS120    equ 10h
EXTBYTE1_BOOTATAPIZIP equ 20h
EXTBYTE1_BOOT1394     equ 40h
EXTBYTE1_SMARTBATTERY equ 80h

; System Information Structure.

SMB_SYSTEM_INFO struct
  header        SMB_STRUCTURE_HEADER <>
  manufacturer$ db ?
  productName$  db ?
  version$      db ?
  serialNumber$ db ?
  uuid          db 16 dup(?)    ; 2.1+
  wakeUpType    db ?            ; 2.1+
  skuNumber$    db ?            ; 2.4+
  family$       db ?            ; 2.4+
SMB_SYSTEM_INFO ends

; Equates for Wake Up Type.

WAKE_UP_TYPE_OTHER          equ 1
WAKE_UP_TYPE_UNKNOWN        equ 2
WAKE_UP_TYPE_APM            equ 3
WAKE_UP_TYPE_MODEM          equ 4
WAKE_UP_TYPE_LAN            equ 5
WAKE_UP_TYPE_POWER_SWITCH   equ 6
WAKE_UP_TYPE_PCI            equ 7
WAKE_UP_TYPE_POWER_RESTORED equ 8
